LiveCurrencyRate class

Constructors

LiveCurrencyRate()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

convertCurrency(String currentCurrency, String toCurrency, double price, {int? timeOutSeconds}) Future<CurrencyRate>
Convert Currency currentCurrency: Currency Code you want to transfer from : USD toCurrency: Currency Code you want to transfer to : CAD price: Amount of currency you want to calucalte Forexample : 1